diff --git a/features.api.php b/features.api.php
index 2f6fcf6..f602e6b 100644
--- a/features.api.php
+++ b/features.api.php
@@ -34,7 +34,7 @@
  *   'default_filename': The filename to use when 'default_file' is set to
  *   FEATURES_DEFAULTS_CUSTOM.
  *
  *   'features_source': Boolean value for whether this component should be
  *   offered as an option on the initial feature creation form.
  *
  *   'base': Optional. An alternative base key to use when calling features
@@ -46,7 +46,7 @@ function hook_features_api() {
     'mycomponent' => array(
       'default_hook' => 'mycomponent_defaults',
       'default_file' => FEATURES_DEFAULTS_INCLUDED,
-      'features_source' => TRUE,
+      'feature_source' => TRUE,
       'file' => drupal_get_path('module', 'mycomponent') .'/mycomponent.features.inc',
     ),
   );
@@ -34,7 +34,7 @@
  *   FEATURES_DEFAULTS_CUSTOM.
  *
- *   'features_source': Boolean value for whether this component should be
+ *   'feature_source': Boolean value for whether this component should be
  *   offered as an option on the initial feature creation form.
  *
